/// Copyright Thomas Nagy 2007
/// License: QPL
#ifndef iztparh
#define iztparh

#include <QDialog>
#include <con.h>

class QSpinBox;
class QTextEdit;
class asdl : public QDialog
<%
	Q_OBJECT
	public:
		asdl(QWidget *felvnl);
		QSpinBox *irnyjl;
		QSpinBox *adelk;
%>;

#endif

